

def log(out_str, o2="", o3="", o4=""):
    """
    Produces console output.
    :param out_str: Output string
    :param o2: Additional output string
    :param o3: Additional output string
    :param o4: Additional output string
    :return: None
    """
    print(out_str, o2, o3, o4)
